@@ -2,6 +2,7 @@ use crate::LangError::{InvalidInstructionCode, InvalidInstructionName};
 use thiserror::Error;
 
 pub mod constants;
+pub mod graphics;
 pub mod input;
 pub mod mem;
 pub mod names;
@@ -23,7 +24,6 @@ pub enum LangError {
     InvalidRegisterArgCode(u8),
 }
 
-pub const SAVE_COUNT: usize = 16;
 pub const MAIKOR_VER: [u8; 2] = [0, 1];
 
 pub fn op_codes(text: &str) -> Result<Vec<u8>, LangError> {
