@@ -6,7 +6,7 @@ pub fn get_byte_count(op: u8) -> usize {
     //each addr +2
     //each num is +1 if byte, +2 if word
     match op {
-        NOP | HALT | RET | RETI | SLEEP => 0,
+        NOP | HALT | RET | RETI | SLEEP | EHALT => 0,
         INC_REG_BYTE | INC_REG_WORD | DEC_REG_BYTE | DEC_REG_WORD | CALL_REG | NOT_REG_BYTE
         | NOT_REG_WORD | ASL_REG_NUM_BYTE | ASL_REG_NUM_WORD | JMP_REG | JL_REG | JG_REG
         | JLE_REG | JGE_REG | JE_REG | JNE_REG | JRF_BYTE | JRB_BYTE => 1,
@@ -293,12 +293,45 @@ pub const SUBC_ADDR_NUM_BYTE: u8 = 0xF4;
 pub const SUBC_ADDR_NUM_WORD: u8 = 0xF5;
 pub const SUBC_ADDR_ADDR_BYTE: u8 = 0xF6;
 pub const SUBC_ADDR_ADDR_WORD: u8 = 0xF7;
-//unused 8 0xF8 - 0xFE
+//unused 8 0xF8 - 0xFD
 
+pub const EHALT: u8 = 0xFE;
 pub const SLEEP: u8 = 0xFF;
 
+///List of ops that MUST affect PC
+/// This means that they unconditionally set PC
+/// however they might set to it's current value
+/// (e.g. if the whole program was 'JMP $0')
+pub const MUST_JMP_OPS: [u8; 8] = [
+    JMP_REG, JMP_ADDR, CALL_ADDR, CALL_REG, RET, RETI, JRF_BYTE, JRB_BYTE,
+];
+
+///List of ops that MAY affect PC
+pub const MAY_JMP_OPS: [u8; 20] = [
+    JL_REG,
+    JL_ADDR,
+    JLE_REG,
+    JLE_ADDR,
+    JG_REG,
+    JG_ADDR,
+    JGE_REG,
+    JGE_ADDR,
+    JE_REG,
+    JE_ADDR,
+    JNE_REG,
+    JNE_ADDR,
+    JBS_REG_REG,
+    JBS_REG_NUM,
+    JBS_ADDR_REG,
+    JBS_ADDR_NUM,
+    JBC_REG_REG,
+    JBC_REG_NUM,
+    JBC_ADDR_REG,
+    JBC_ADDR_NUM,
+];
+
 #[rustfmt::skip]
-pub const ALL: [u8; 213] = [
+pub const ALL: [u8; 214] = [
     NOP, HALT,
     CALL_ADDR, CALL_REG, RET, RETI,
     CPY_REG_REG_BYTE, CPY_REG_REG_WORD, CPY_ADDR_REG_BYTE, CPY_ADDR_REG_WORD,
@@ -357,7 +390,8 @@ pub const ALL: [u8; 213] = [
     SUBC_REG_REG_BYTE, SUBC_REG_REG_WORD, SUBC_REG_NUM_BYTE, SUBC_REG_NUM_WORD,
     SUBC_REG_ADDR_BYTE, SUBC_REG_ADDR_WORD, SUBC_ADDR_REG_BYTE, SUBC_ADDR_REG_WORD,
     SUBC_ADDR_NUM_BYTE, SUBC_ADDR_NUM_WORD, SUBC_ADDR_ADDR_BYTE, SUBC_ADDR_ADDR_WORD,
-    SLEEP
+    EHALT,
+    SLEEP,
 ];
 
 #[cfg(test)]
